@@ -225,9 +225,9 @@ type LicenseReporting struct {
 
 // NginxLicense contains licensing information about NGINX Plus.
 type NginxLicense struct {
+	Reporting  *LicenseReporting
 	ActiveTill uint64 `json:"active_till"`
 	Eval       bool
-	Reporting  LicenseReporting
 }
 
 // Caches is a map of cache stats by cache zone.
@@ -262,10 +262,10 @@ type ExtendedCacheStats struct {
 
 // Connections represents connection related stats.
 type Connections struct {
-	Accepted uint64
-	Dropped  uint64
-	Active   uint64
-	Idle     uint64
+	Accepted int64
+	Dropped  int64
+	Active   int64
+	Idle     int64
 }
 
 // Slabs is map of slab stats by zone name.
@@ -1002,7 +1002,7 @@ func determineUpdates(updatedServers []UpstreamServer, nginxServers []UpstreamSe
 		}
 	}
 
-	return
+	return toAdd, toRemove, toUpdate
 }
 
 func (client *NginxClient) getIDOfHTTPServer(ctx context.Context, upstream string, name string) (int, error) {
@@ -1376,7 +1376,7 @@ func determineStreamUpdates(updatedServers []StreamUpstreamServer, nginxServers
 		}
 	}
 
-	return
+	return toAdd, toRemove, toUpdate
 }
 
 // GetStats gets process, slab, connection, request, ssl, zone, stream zone, upstream and stream upstream related stats from the NGINX Plus API.
