@@ -7,8 +7,8 @@ import (
 	"testing"
 	"time"
 
-	"github.com/nginx/nginx-plus-go-client/v2/client"
-	"github.com/nginx/nginx-plus-go-client/v2/tests/helpers"
+	"github.com/nginx/nginx-plus-go-client/v3/client"
+	"github.com/nginx/nginx-plus-go-client/v3/tests/helpers"
 )
 
 const (
@@ -850,7 +850,8 @@ func TestStreamStats(t *testing.T) {
 	}
 
 	// make connection so we have stream server zone stats - ignore response
-	_, err = net.Dial("tcp", helpers.GetStreamAddress())
+	d := &net.Dialer{}
+	_, err = d.DialContext(context.Background(), "tcp", helpers.GetStreamAddress())
 	if err != nil {
 		t.Errorf("Error making tcp connection: %v", err)
 	}
